@@ -36,14 +36,18 @@ To persist a cube to the file-system, use the :func:`save` function.
 All the load functions share very similar arguments:
 
     * uris:
-        Either a single filename/URI expressed as a string, or an
-        iterable of filenames/URIs.
+        Either a single filename/URI expressed as a string or
+        :class:`pathlib.PurePath`, or an iterable of filenames/URIs.
 
         Filenames can contain `~` or `~user` abbreviations, and/or
         Unix shell-style wildcards (e.g. `*` and `?`). See the
         standard library function :func:`os.path.expanduser` and
         module :mod:`fnmatch` for more details.
 
+        .. warning::
+
+            If supplying a URL, only OPeNDAP Data Sources are supported.
+
     * constraints:
         Either a single constraint, or an iterable of constraints.
         Each constraint can be either a string, an instance of
@@ -89,16 +93,14 @@ import contextlib
 import glob
 import itertools
 import os.path
+import pathlib
 import threading
 
-import iris.config
-import iris.cube
 import iris._constraints
 from iris._deprecation import IrisDeprecation, warn_deprecated
-import iris.fileformats
+import iris.config
 import iris.io
 
-
 try:
     import iris_sample_data
 except ImportError:
@@ -106,23 +108,23 @@ except ImportError:
 
 
 # Iris revision.
-__version__ = "3.0.3"
+__version__ = "3.2.0.post0"
 
 # Restrict the names imported when using "from iris import *"
 __all__ = [
+    "AttributeConstraint",
+    "Constraint",
+    "FUTURE",
+    "Future",
+    "IrisDeprecation",
+    "NameConstraint",
     "load",
     "load_cube",
     "load_cubes",
     "load_raw",
-    "save",
-    "Constraint",
-    "AttributeConstraint",
-    "NameConstraint",
     "sample_data_path",
+    "save",
     "site_configuration",
-    "Future",
-    "FUTURE",
-    "IrisDeprecation",
 ]
 
 
@@ -244,7 +246,7 @@ else:
 
 def _generate_cubes(uris, callback, constraints):
     """Returns a generator of cubes given the URIs and a callback."""
-    if isinstance(uris, str):
+    if isinstance(uris, (str, pathlib.PurePath)):
         uris = [uris]
 
     # Group collections of uris by their iris handler
@@ -266,9 +268,11 @@ def _generate_cubes(uris, callback, constraints):
 
 
 def _load_collection(uris, constraints=None, callback=None):
+    from iris.cube import _CubeFilterCollection
+
     try:
         cubes = _generate_cubes(uris, callback, constraints)
-        result = iris.cube._CubeFilterCollection.from_cubes(cubes, constraints)
+        result = _CubeFilterCollection.from_cubes(cubes, constraints)
     except EOFError as e:
         raise iris.exceptions.TranslationError(
             "The file appears empty or incomplete: {!r}".format(str(e))
@@ -286,7 +290,8 @@ def load(uris, constraints=None, callback=None):
     Args:
 
     * uris:
-        One or more filenames/URIs.
+        One or more filenames/URIs, as a string or :class:`pathlib.PurePath`.
+        If supplying a URL, only OPeNDAP Data Sources are supported.
 
     Kwargs:
 
@@ -314,7 +319,8 @@ def load_cube(uris, constraint=None, callback=None):
     Args:
 
     * uris:
-        One or more filenames/URIs.
+        One or more filenames/URIs, as a string or :class:`pathlib.PurePath`.
+        If supplying a URL, only OPeNDAP Data Sources are supported.
 
     Kwargs:
 
@@ -353,7 +359,8 @@ def load_cubes(uris, constraints=None, callback=None):
     Args:
 
     * uris:
-        One or more filenames/URIs.
+        One or more filenames/URIs, as a string or :class:`pathlib.PurePath`.
+        If supplying a URL, only OPeNDAP Data Sources are supported.
 
     Kwargs:
 
@@ -398,7 +405,8 @@ def load_raw(uris, constraints=None, callback=None):
     Args:
 
     * uris:
-        One or more filenames/URIs.
+        One or more filenames/URIs, as a string or :class:`pathlib.PurePath`.
+        If supplying a URL, only OPeNDAP Data Sources are supported.
 
     Kwargs:
 
