@@ -10,20 +10,19 @@ Unit tests for :class:`iris.analysis._interpolation.RectilinearInterpolator`.
 
 # Import iris.tests first so that some things can be initialised before
 # importing anything else.
-import iris.tests as tests
+import iris.tests as tests  # isort:skip
 
 import datetime
 
-from iris._lazy_data import as_lazy_data
 import numpy as np
 
 import iris
+from iris._lazy_data import as_lazy_data
+from iris.analysis._interpolation import RectilinearInterpolator
 import iris.coords
 import iris.cube
 import iris.exceptions
 import iris.tests.stock as stock
-from iris.analysis._interpolation import RectilinearInterpolator
-
 
 LINEAR = "linear"
 NEAREST = "nearest"
