@@ -7,7 +7,7 @@
 
 # Import iris.tests first so that some things can be initialised before
 # importing anything else.
-import iris.tests as tests
+import iris.tests as tests  # isort:skip
 
 import collections
 from unittest import mock
@@ -17,12 +17,11 @@ import dask.array as da
 import numpy as np
 
 import iris
+from iris.coords import AuxCoord, Coord, DimCoord
 from iris.cube import Cube
-from iris.coords import DimCoord, AuxCoord, Coord
 from iris.exceptions import UnitConversionError
 from iris.tests.unit.coords import CoordTestMixin
 
-
 Pair = collections.namedtuple("Pair", "points bounds")
 
 
@@ -884,9 +883,14 @@ class Test___str__(tests.IrisTest):
         coord = DimCoord(
             [5], standard_name="time", units="days since 1970-01-01"
         )
-        expected = (
-            "DimCoord([1970-01-06 00:00:00], standard_name='time', "
-            "calendar='gregorian')"
+        expected = "\n".join(
+            [
+                "DimCoord :  time / (days since 1970-01-01, gregorian calendar)",
+                "    points: [1970-01-06 00:00:00]",
+                "    shape: (1,)",
+                "    dtype: int64",
+                "    standard_name: 'time'",
+            ]
         )
         result = coord.__str__()
         self.assertEqual(expected, result)
@@ -896,11 +900,17 @@ class Test___str__(tests.IrisTest):
             [5, 6], standard_name="time", units="days since 1970-01-01"
         )
         coord.guess_bounds()
-        expected = (
-            "DimCoord([1970-01-06 00:00:00, 1970-01-07 00:00:00], "
-            "bounds=[[1970-01-05 12:00:00, 1970-01-06 12:00:00],\n"
-            "       [1970-01-06 12:00:00, 1970-01-07 12:00:00]], "
-            "standard_name='time', calendar='gregorian')"
+        expected = "\n".join(
+            [
+                "DimCoord :  time / (days since 1970-01-01, gregorian calendar)",
+                "    points: [1970-01-06 00:00:00, 1970-01-07 00:00:00]",
+                "    bounds: [",
+                "        [1970-01-05 12:00:00, 1970-01-06 12:00:00],",
+                "        [1970-01-06 12:00:00, 1970-01-07 12:00:00]]",
+                "    shape: (2,)  bounds(2, 2)",
+                "    dtype: int64",
+                "    standard_name: 'time'",
+            ]
         )
         result = coord.__str__()
         self.assertEqual(expected, result)
@@ -909,7 +919,15 @@ class Test___str__(tests.IrisTest):
         coord = DimCoord(
             [5], standard_name="time", units="years since 1970-01-01"
         )
-        expected = "DimCoord([5], standard_name='time', calendar='gregorian')"
+        expected = "\n".join(
+            [
+                "DimCoord :  time / (years since 1970-01-01, gregorian calendar)",
+                "    points: [5]",
+                "    shape: (1,)",
+                "    dtype: int64",
+                "    standard_name: 'time'",
+            ]
+        )
         result = coord.__str__()
         self.assertEqual(expected, result)
 
@@ -918,16 +936,31 @@ class Test___str__(tests.IrisTest):
             [5, 6], standard_name="time", units="years since 1970-01-01"
         )
         coord.guess_bounds()
-        expected = (
-            "DimCoord([5 6], bounds=[[4.5 5.5]\n [5.5 6.5]], "
-            "standard_name='time', calendar='gregorian')"
+        expected = "\n".join(
+            [
+                "DimCoord :  time / (years since 1970-01-01, gregorian calendar)",
+                "    points: [5, 6]",
+                "    bounds: [",
+                "        [4.5, 5.5],",
+                "        [5.5, 6.5]]",
+                "    shape: (2,)  bounds(2, 2)",
+                "    dtype: int64",
+                "    standard_name: 'time'",
+            ]
         )
         result = coord.__str__()
         self.assertEqual(expected, result)
 
     def test_non_time_unit(self):
         coord = DimCoord([1.0])
-        expected = repr(coord)
+        expected = "\n".join(
+            [
+                "DimCoord :  unknown / (unknown)",
+                "    points: [1.]",
+                "    shape: (1,)",
+                "    dtype: float64",
+            ]
+        )
         result = coord.__str__()
         self.assertEqual(expected, result)
 
